==> jc-1.4.0.tar.gz: soot/shimple/internal/OneHeadBlockGraph.h <==
// public class soot.shimple.internal.OneHeadBlockGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ff4b4cec1ffbbcb soot_shimple_internal_OneHeadBlockGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_OneHeadBlockGraph_H_
#define _JC_soot_shimple_internal_OneHeadBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_BlockGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs	_jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs	_jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$refs	_jc_soot_shimple_internal_OneHeadBlockGraph$refs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs	_jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$object	_jc_soot_shimple_internal_OneHeadBlockGraph$object;

typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vmethods	_jc_soot_shimple_internal_OneHeadBlockGraph$vmethods;
typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtable	_jc_soot_shimple_internal_OneHeadBlockGraph$vtable;
typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtype	_jc_soot_shimple_internal_OneHeadBlockGraph$vtype;

// Constructors
extern void _jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_internal_OneHeadBlockGraph$object *);

// Static methods
extern void _jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82(_jc_env *, struct _jc_soot_toolkits_graph_BlockGraph$object *);

// Virtual methods structure
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vmethods	soot_shimple_internal_OneHeadBlockGraph;
};

// Vtype
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$refs {
    _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs	soot_shimple_internal_OneHeadBlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs	soot_shimple_internal_OneHeadBlockGraph;
};

// Object instance structure
struct _jc_soot_shimple_internal_OneHeadBlockGraph$object {
	_jc_soot_shimple_internal_OneHeadBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vtype	*vtype;
	_jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_OneHeadBlockGraph$vtype _jc_soot_shimple_internal_OneHeadBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_OneHeadBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_OneHeadBlockGraph$class_object;

#endif	/* _JC_soot_shimple_internal_OneHeadBlockGraph_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/OneHeadBlockGraph.h <==
// public class soot.shimple.internal.OneHeadBlockGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ff4b4cec1ffbbcb soot_shimple_internal_OneHeadBlockGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_OneHeadBlockGraph_H_
#define _JC_soot_shimple_internal_OneHeadBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_toolkits_graph_BlockGraph$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs	_jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs	_jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$refs	_jc_soot_shimple_internal_OneHeadBlockGraph$refs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs	_jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs;
typedef struct _jc_soot_shimple_internal_OneHeadBlockGraph$object	_jc_soot_shimple_internal_OneHeadBlockGraph$object;

typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vmethods	_jc_soot_shimple_internal_OneHeadBlockGraph$vmethods;
typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtable	_jc_soot_shimple_internal_OneHeadBlockGraph$vtable;
typedef const struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtype	_jc_soot_shimple_internal_OneHeadBlockGraph$vtype;

// Constructors
extern void _jc_soot_shimple_internal_OneHeadBlockGraph$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_internal_OneHeadBlockGraph$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_shimple_internal_OneHeadBlockGraph$method$convert$1e4e5b4571f54a82(_jc_env *, struct _jc_soot_toolkits_graph_BlockGraph$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vmethods	soot_shimple_internal_OneHeadBlockGraph;
};

// Vtype
struct _jc_soot_shimple_internal_OneHeadBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$refs {
    _jc_soot_shimple_internal_OneHeadBlockGraph$sub_refs	soot_shimple_internal_OneHeadBlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_OneHeadBlockGraph$sub_nonrefs	soot_shimple_internal_OneHeadBlockGraph;
};

// Object instance structure
struct _jc_soot_shimple_internal_OneHeadBlockGraph$object {
	_jc_soot_shimple_internal_OneHeadBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_OneHeadBlockGraph$vtype	*vtype;
	_jc_soot_shimple_internal_OneHeadBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_OneHeadBlockGraph$vtype _jc_soot_shimple_internal_OneHeadBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_OneHeadBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_OneHeadBlockGraph$class_object;

#endif	/* _JC_soot_shimple_internal_OneHeadBlockGraph_H_ */
